@@ -3,8 +3,8 @@ tmpfile = 'tmp'
 object_label_upper = 'Gene'
 object_label_lower = 'gene'
 outputwidth = 73
-version = 'v1.12.0'
-email = 'basel.abu-jamous@sensynehealth.com'
+version = 'v1.13.0'
+email = 'baselabujamous@gmail.com'
 maxgenesinsetforpdist = 10000
 print_to_log_file = True
 print_to_console = True
